aboutsummaryrefslogtreecommitdiff
path: root/Utility/Gpg.hs
diff options
context:
space:
mode:
Diffstat (limited to 'Utility/Gpg.hs')
-rw-r--r--Utility/Gpg.hs5
1 files changed, 3 insertions, 2 deletions
diff --git a/Utility/Gpg.hs b/Utility/Gpg.hs
index f3a1ac0bb..b50e775d0 100644
--- a/Utility/Gpg.hs
+++ b/Utility/Gpg.hs
@@ -28,8 +28,9 @@ stdParams params = do
let batch = if isNothing e then [] else ["--batch"]
return $ batch ++ defaults ++ toCommand params
where
- -- be quiet, even about checking the trustdb
- defaults = ["--quiet", "--trust-model", "always"]
+ -- be quiet, even about checking the trustdb,
+ -- and avoid using a tty
+ defaults = ["--quiet", "--trust-model", "always", "--no-tty"]
{- Runs gpg with some params and returns its stdout, strictly. -}
readStrict :: [CommandParam] -> IO String